import os
from unittest import TestCase

from ebi_eva_common_pyutils.common_utils import merge_two_dicts, pretty_print


class TestCommon(TestCase):

    resources_folder = os.path.join(os.path.dirname(__file__), 'resources')


class TestCommonUtils(TestCase):

    def test_merge_two_dicts(self):
        d1 = {'a': 1, 'b': 2, 'c': 3}
        d2 = {'d': 4, 'a': 5, 'e': 6}
        assert merge_two_dicts(d1, d2) == {'a': 5, 'b': 2, 'c': 3, 'd': 4, 'e': 6}
        assert merge_two_dicts(d2, d1) == {'a': 1, 'b': 2, 'c': 3, 'd': 4, 'e': 6}

    def test_pretty_print(self):
        pretty_print(['Header 1', 'Long Header 2'],
                     [['row1 cell 1', 'row1 cell 2'], ['row2 cell 1', 'Super long row2 cell 2']])



import os
from distutils.core import setup
from os.path import abspath, dirname, join

from setuptools import find_packages
base_dir = abspath(dirname(__file__))
requirements_txt = join(base_dir, 'requirements.txt')
requirements = [l.strip() for l in open(requirements_txt) if l and not l.startswith('#')]

setup(
    name='ebi_eva_common_pyutils',
    scripts=[os.path.join(os.path.dirname(__file__), 'ebi_eva_internal_pyutils', 'archive_directory.py')],
    packages=find_packages(),
    version='0.8.3',
    license='Apache',
    description='EBI EVA - Common Python Utilities',
    url='https://github.com/EBIVariation/eva-common-pyutils',
    keywords=['EBI', 'EVA', 'PYTHON', 'UTILITIES'],
    install_requires=requirements,
    extras_require={'eva-internal': ['psycopg2-binary', 'pymongo<=3.12', 'networkx<=2.5']},
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Build Tools',
        'License :: OSI Approved :: Apache Software License',
        'Programming Language :: Python :: 3'
    ]
)
